@@ -171,6 +171,13 @@ class UWC_Context {
   }
 
   function update_action(&$content) {
+    switch ($this->request->get_value("action")) {
+    case "loginform":
+    case "logout":
+    case "about":
+      $this->action=$this->request->get_value("action");
+      break;
+    default:
     switch ($this->mode) {
     case "create":
     case "update": 
@@ -181,7 +188,7 @@ class UWC_Context {
       if ($this->auth->can_edit($this->get_path(),$content->get_status())) {
 	$this->action=$this->mode;
       } else {	
-	$this->action="login";
+	$this->action="loginform";
       }
       break;
     case "clearcache":
@@ -189,16 +196,13 @@ class UWC_Context {
       if ($this->auth->can_admin()) {
 	$this->action=$this->mode;
       } else {	
-	$this->action="login";
+	$this->action="loginform";
       }
       break;
     case "new":
       $this->path=uwc_contextutils_fix_path($this->get_path()."/".$this->request->get_value("page"));
       $this->action=$this->mode;
       break;
-    case "login":
-    case "loginform":
-    case "logout":
     case "about":
       $this->action=$this->mode;
       break;
@@ -280,6 +284,7 @@ class UWC_Context {
 	uwc_external_exists($this->conf, $this->get_path(), $this->get_lang())) {
       $this->action="external";
     }
+    }
   }
 
   function update_gui() {
