@@ -534,6 +534,10 @@ class UWC_Page {
     return $this->make_url("/_uwikicms/clearcache.php",array("continue"=>$this->get_path()));
   }
 
+  function get_help_url() {
+    return "http://www.ufoot.org/uwikicms/doc/manual";
+  }
+
   function get_allinoneform_url() {
     return $this->make_url($this->get_path(),array("action"=>"allinoneform"));
   }
@@ -877,6 +881,10 @@ class UWC_Page {
     return $this->context->action!="clearcacheform" && $this->context->action!="clearcache" && $this->auth->can_admin();
   }
 
+  function need_action_help() {
+    return $this->get_user_status()>=2;
+  }
+
   function need_action_allinone() {
     return ($this->context->action=="view" || $this->context->action=="tree" || $this->context->action=="external") && $this->auth->can_admin() && $this->viewable();
   }
